@@ -280,7 +280,7 @@ class NlpClient(AbstractClient):
 
 
     def DescribeEntity(self, request):
-        """输入实体名称，返回实体相关的信息如实体别名、实体英文名、实体详细信息、相关实体等。
+        """此接口正在维护升级，后续上线另行通知。
 
         :param request: Request instance for DescribeEntity.
         :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeEntityRequest`
@@ -308,7 +308,7 @@ class NlpClient(AbstractClient):
 
 
     def DescribeRelation(self, request):
-        """输入两个实体，返回两个实体间的关系，例如马化腾与腾讯公司不仅是相关实体，二者还存在隶属关系（马化腾属于腾讯公司）。
+        """此接口正在维护升级，后续上线另行通知。
 
         :param request: Request instance for DescribeRelation.
         :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeRelationRequest`
@@ -336,7 +336,7 @@ class NlpClient(AbstractClient):
 
 
     def DescribeTriple(self, request):
-        """三元组查询，主要分为两类，SP查询和PO查询。SP查询表示已知主语和谓语查询宾语，PO查询表示已知宾语和谓语查询主语。每一个SP或PO查询都是一个可独立执行的查询，TQL支持SP查询的嵌套查询，即主语可以是一个嵌套的子查询。其他复杂的三元组查询方法，请参考官网API文档示例。
+        """此接口正在维护升级，后续上线另行通知。
 
         :param request: Request instance for DescribeTriple.
         :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeTripleRequest`
@@ -637,6 +637,36 @@ class NlpClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def TextCorrectionPro(self, request):
+        """提供对中文文本的自动纠错功能，能够识别输入文本中的错误片段，定位错误并给出正确的文本结果；支持长度不超过128字符（含标点符号）的长文本纠错。
+
+        此功能是基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升，是搜索引擎、语音识别、内容审核等功能更好运行的基础之一。
+
+        :param request: Request instance for TextCorrectionPro.
+        :type request: :class:`tencentcloud.nlp.v20190408.models.TextCorrectionProRequest`
+        :rtype: :class:`tencentcloud.nlp.v20190408.models.TextCorrectionProResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("TextCorrectionPro", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.TextCorrectionProResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def TextSimilarity(self, request):
         """句子相似度接口能够基于深度学习技术来计算一个源句子和多个目标句子的相似度，相似度分值越大的两个句子在语义上越相似。目前仅支持短文本（不超过500字符）的相似度计算，长文本的相似度计算也即将推出。
 
@@ -669,6 +699,38 @@ class NlpClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def TextSimilarityPro(self, request):
+        """句子相似度接口能够基于深度学习技术来计算一个源句子和多个目标句子的相似度，相似度分值越大的两个句子在语义上越相似。目前仅支持短文本（不超过128字符）的相似度计算，长文本的相似度计算也即将推出。
+
+        鉴于句子相似度是一个应用非常广泛的功能，腾讯云自然语言处理团队在Bert等领先的深度神经网络模型的基础上，专门针对文本相似任务进行了优化，并持续迭代更新。基于句子相似度，可以轻松实现诸如文本去重、相似推荐等功能。
+
+        接口将以句子数量为单位消耗资源包，而不是调用接口次数为单位。
+
+        :param request: Request instance for TextSimilarityPro.
+        :type request: :class:`tencentcloud.nlp.v20190408.models.TextSimilarityProRequest`
+        :rtype: :class:`tencentcloud.nlp.v20190408.models.TextSimilarityProResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("TextSimilarityPro", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.TextSimilarityProResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateDict(self, request):
         """修改自定义词库元数据信息，包括名称、描述。
 
